"""
This method is going to iterate through list and n Sublist and display the Values
"""

def print_list (the_list) :
    #Use recursive function limits to 1000 iterations

    for litem in (the_list) :
        if (isinstance (litem,list)) :
            print_list(litem)
        else:
            print(litem)


from distutils.core import setup

setup (
	name ='Listing',
	version = "1.2.0",
	py_modules = ['Listing'],
	author = "Santanu",
	author_email = "ghosalsantanuit@gmail.com",
	url = "http://wastelandersdiary.blogspot.com/",
	description = "A Simple Python List Reader using Nested Function"
	)
